# Generated by Django 3.2.7 on 2021-09-05 17:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0128_images_file_name'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='images',
            unique_together={('file_name', 'size')},
        ),
    ]
