# Generated by Django 3.2.3 on 2021-05-14 15:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0088_alter_messages_files_real_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages_files',
            name='real_name',
            field=models.TextField(db_index=True, unique=True, verbose_name='Первоначальное имя файла'),
        ),
    ]
