# Generated by Django 3.2.7 on 2021-09-22 18:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0133_auto_20210916_1226'),
    ]

    operations = [
        migrations.AlterField(
            model_name='text_informations',
            name='text',
            field=models.TextField(),
        ),
    ]
